@@ -1,3 +1,4 @@
+use super::*;
 use super::{Drawable, PointCollection};
 use crate::drawing::backend::{BackendCoord, DrawingBackend, DrawingErrorKind};
 use crate::style::ShapeStyle;
@@ -53,3 +54,9 @@ impl<'a, Coord> PointElement<'a, Coord> for Cross<'a, Coord> {
         return Self::new(pos, size, style);
     }
 }
+
+impl<'a, Coord> PointElement<'a, Coord> for Circle<'a, Coord> {
+    fn make_point(pos: Coord, size: u32, style: ShapeStyle<'a>) -> Self {
+        return Self::new(pos, size, style);
+    }
+}
