@@ -15,16 +15,16 @@
 Plotters is a flexible drawing library for data visualization written in pure Rust.
 
 - Why plotting in Rust?
-Although rendering a figure doesn't requires too many computation power in most of the case, 
+Although rendering a figure doesn't requires too many computation power in most of the case,
 and programming language such as Python and Javascript is used for visualization purpose.
 Sometimes we need to make a figure based on huge amount of data, for example, rendering some
 human gene data may requires to downsampling trillions data points, which isn't even doable
-with many high-level programming language. In this case, Rust is a perfect candidate for rendering 
-figures, since it runs very fast while having high-level abstraction abilities. 
+with many high-level programming language. In this case, Rust is a perfect candidate for rendering
+figures, since it runs very fast while having high-level abstraction abilities.
 
 - What type of figure is supported?
-Currently, we support line series, point series and candlestick series. 
-And the library is designed to be able to render multiple figure into a single image. 
+Currently, we support line series, point series and candlestick series.
+And the library is designed to be able to render multiple figure into a single image.
 But Plotter is aimed to be a platform that is fully extendable to supporting any other types of figure.
 
 
@@ -65,20 +65,21 @@ But Plotter is aimed to be a platform that is fully extendable to supporting any
 ```rust
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let mut backend = BitMapBackend::new("examples/outputs/0.png", (640,480));
+    let mut backend = BitMapBackend::new("examples/outputs/0.png", (640, 480));
     backend.open()?;
-    let root:DrawingArea<_,_> = backend.into();
+    let root: DrawingArea<_, _> = backend.into();
     let font = Into::<FontDesc>::into("Arial").resize(20.0);
-    root.fill(&RGBColor(255,255,255))?;
+    root.fill(&RGBColor(255, 255, 255))?;
     let mut chart = ChartBuilder::on(&root)
         .caption("y=x^2", &font)
-        .build_ranged::<RangedCoordf32, RangedCoordf32, _, _>(-1f32..1f32, 0f32..1f32);
+        .set_x_label_size(30)
+        .set_y_label_size(30)
+        .build_ranged::<RangedCoordf32, RangedCoordf32, _, _>(-1f32..1f32, -0.1f32..1f32);
 
-    chart.configure_mesh()
-        .draw()?;
+    chart.configure_mesh().draw()?;
 
     chart.draw_series(LineSeries::new(
-        (-50..=50).map(|x| x as f32 / 50.0).map(|x| (x, x*x)),
+        (-50..=50).map(|x| x as f32 / 50.0).map(|x| (x, x * x)),
         &RGBColor(255, 0, 0),
     ))?;
 
@@ -156,7 +157,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let root:DrawingArea<_,_> = backend.into();
     root.fill(&RGBColor(255,255,255));
     // Draw an circle on the drawing area
-    root.draw(&Circle::new((100,100), 50, Into::<ShapeStyle>::into(&RGBColor(0, 255, 0))))?;
+    root.draw(&Circle::new((100,100), 50, Into::<ShapeStyle>::into(&RGBColor(0, 255, 0)).filled()))?;
     root.close()?;
     return Ok(());
 }
@@ -303,5 +304,6 @@ pub mod prelude {
     /// The type used to returns a drawing operation that can be failed
     /// - `T`: The return type
     /// - `D`: The drawing backend type
-    pub type DrawResult<T, D:DrawingBackend>=Result<T, crate::drawing::DrawingAreaErrorKind<D::ErrorType>>;
+    pub type DrawResult<T, D: DrawingBackend> =
+        Result<T, crate::drawing::DrawingAreaErrorKind<D::ErrorType>>;
 }
